@@ -7,7 +7,7 @@
 __copyright__ = """
     pySART - Simplified AUTOSAR-Toolkit for Python.
 
-   (C) 2009-2019 by Christoph Schueler <cpu12.gems@googlemail.com>
+   (C) 2009-2021 by Christoph Schueler <cpu12.gems@googlemail.com>
 
    All Rights Reserved
 
@@ -31,15 +31,39 @@ from pprint import pprint
 
 from pyxcp.cmdline import ArgumentParser
 
-ap = ArgumentParser(description="pyXCP hello world.")
+daq_info = False
+
+def callout(master, args):
+    global daq_info
+    if args.daq_info:
+        daq_info = True
+
+
+ap = ArgumentParser(description = "pyXCP hello world.", callout = callout)
+ap.parser.add_argument("-d", "--daq-info", dest = "daq_info", help = "Display DAQ-info", default = False, action = "store_true")
 with ap.run() as x:
     x.connect()
     if x.slaveProperties.optionalCommMode:
         x.getCommModeInfo()
-    gid = x.getId(0x1)
+    #gid = x.getId(0x1)
+    gid = x.getId(0x80)
     result = x.fetch(gid.length)
-    x.disconnect()
     print("\nSlave properties:")
     print("=================")
     print("ID: '{}'".format(result.decode("utf8")))
     pprint(x.slaveProperties)
+
+    if daq_info:
+        dqp = x.getDaqProcessorInfo()
+        print("\nDAQProcessor info:")
+        print("==================")
+        print(dqp)
+        dqr = x.getDaqResolutionInfo()
+        print("\nDAQResolution info:")
+        print("===================")
+        print(dqr)
+        for idx in range(dqp.maxDaq):
+            print("\nDAQList info #{}".format(idx))
+            print("================")
+            print("{}".format(x.getDaqListInfo(idx)))
+    x.disconnect()
