@@ -31,7 +31,6 @@ from time import perf_counter, time, sleep
 import threading
 
 from pyxcp.transport.base import BaseTransport
-import pyxcp.types as types
 
 DEFAULT_XCP_PORT = 5555
 RECV_SIZE = 8196
@@ -99,7 +98,7 @@ class Eth(BaseTransport):
     def startListener(self):
         self._packet_listener.start()
         self.listener.start()
-        
+
     def close(self):
         """Close the transport-layer connection and event-loop."""
         self.finishListener()
@@ -113,7 +112,7 @@ class Eth(BaseTransport):
         use_tcp = self.use_tcp
         EVENT_READ = selectors.EVENT_READ
 
-        close_event_set = self.closeEvent.isSet
+        close_event_set = self.closeEvent.is_set
         socket_fileno = self.sock.fileno
         select = self.selector.select
 
@@ -141,10 +140,21 @@ class Eth(BaseTransport):
                             recv_timestamp = timestamp_origin + perf_counter() - perf_counter_origin
 
                         if use_tcp:
-                            _packets.append((sock_recv(RECV_SIZE), recv_timestamp))
+                            response = sock_recv(RECV_SIZE)
+                            if not response:
+                                self.sock.close()
+                                self.status = 0
+                                break
+                            else:
+                                _packets.append((response, recv_timestamp))
                         else:
                             response, _ = sock_recv(Eth.MAX_DATAGRAM_SIZE)
-                            _packets.append((response, recv_timestamp))
+                            if not response:
+                                self.sock.close()
+                                self.status = 0
+                                break
+                            else:
+                                _packets.append((response, recv_timestamp))
             except:
                 self.status = 0  # disconnected
                 break
@@ -155,7 +165,7 @@ class Eth(BaseTransport):
         processResponse = self.processResponse
         popleft = self._packets.popleft
 
-        close_event_set = self.closeEvent.isSet
+        close_event_set = self.closeEvent.is_set
         socket_fileno = self.sock.fileno
 
         _packets = self._packets
@@ -191,7 +201,8 @@ class Eth(BaseTransport):
                             break
                     else:
                         if current_size >= length:
-                            response = memoryview(data[current_position : current_position + length])
+                            #response = memoryview(data[current_position : current_position + length])
+                            response = data[current_position : current_position + length]
                             processResponse(response, length, counter, timestamp)
 
                             current_size -= length
